==> fahviewer_7.3.3-64bit-release.tar.bz2: fahviewer_7.3.3-64bit-release/src/fah/viewer/Bond.h <==
/******************************************************************************\

                     This file is part of the FAHViewer.

           The FAHViewer displays 3D views of Folding@home proteins.
                 Copyright (c) 2003-2013, Stanford University
                             All rights reserved.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

                For information regarding this software email:
                               Joseph Coffland
                        joseph@cauldrondevelopment.com

\******************************************************************************/

#ifndef FAH_BOND_H
#define FAH_BOND_H

#include <cbang/StdTypes.h>

#include <cbang/pyon/Object.h>


namespace FAH {
  class Bond : public cb::PyON::Object {
  public:
    uint32_t left;
    uint32_t right;

    Bond() : left(0), right(0) {}
    Bond(const cb::PyON::Value &value) : left(0), right(0) {loadPyON(value);}
    Bond(uint32_t left, uint32_t right) : left(left), right(right) {}

    // From PyONObject
    const char *getPyONType() const {return "bond";}
    cb::SmartPointer<cb::PyON::Value> getPyON() const;
    void loadPyON(const cb::PyON::Value &value);
  };
}

#endif // FAH_BOND_H

==> fahviewer_7.4.2-32bit-release.tar.bz2: fahviewer_7.4.2-32bit-release/src/fah/viewer/Bond.h <==
/******************************************************************************\

                     This file is part of the FAHViewer.

           The FAHViewer displays 3D views of Folding@home proteins.
                 Copyright (c) 2003-2013, Stanford University
                             All rights reserved.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

                For information regarding this software email:
                               Joseph Coffland
                        joseph@cauldrondevelopment.com

\******************************************************************************/

#ifndef FAH_BOND_H
#define FAH_BOND_H

#include <cbang/StdTypes.h>

#include <cbang/pyon/Object.h>


namespace FAH {
  class Bond : public cb::PyON::Object {
  public:
    uint32_t left;
    uint32_t right;

    Bond() : left(0), right(0) {}
    Bond(const cb::JSON::Value &value) : left(0), right(0) {loadJSON(value);}
    Bond(uint32_t left, uint32_t right) : left(left), right(right) {}

    // From PyONObject
    const char *getPyONType() const {return "bond";}
    cb::SmartPointer<cb::JSON::Value> getJSON() const;
    void loadJSON(const cb::JSON::Value &value);
  };
}

#endif // FAH_BOND_H
